#undef HAVE_LC_MESSAGES
#undef HAVE_STPCPY
#undef PACKAGE
#undef VERSION
#undef ENABLE_NLS
#undef HAVE_CATGETS
#undef HAVE_GETTEXT
#undef HAVE_GMP2_INCLUDE_DIR
#undef HAVE_LIBSM
#undef HAVE_PROGRAM_INVOCATION_NAME
#undef HAVE_PROGRAM_INVOCATION_SHORT_NAME
#undef HAVE_SHADOW_H
#undef HAVE_LINUX_TABLE

/* Define if your struct tm has tm_gmtoff.  */
#undef HAVE_TM_GMTOFF

/* Define if you don't have tm_gmtoff but do have the external timezone.  */
#undef HAVE_TIMEZONE

/* Define if you want to build against development gtk */
#undef HAVE_DEVGTK

/* Define if there is no `u_int64_t' and `int64_t'. */
#undef u_int64_t
#undef int64_t

